"use client";

import { ChevronDown, User } from "lucide-react";
import { useTranslations } from "next-intl";

import {
	DropdownMenu,
	DropdownMenuContent,
	DropdownMenuItem,
	DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";
import { Link, Locale, ValidHref } from "@/i18n/routing";
import { cn } from "@/lib/utils";

type NavItem = {
	href: ValidHref;
	labelKey: string;
	active?: boolean;
	hasDropdown?: boolean;
	dropdownItems?: Array<{
		id: number;
		href: ValidHref;
		labelKey: string;
	}>;
};

const navItems: NavItem[] = [
	{ href: "/products/product-details", labelKey: "library" },
	{ href: "/shop", labelKey: "products" },
	{ href: "/projects", labelKey: "projects" },
	{
		href: "/services",
		labelKey: "services",
		hasDropdown: true,
		dropdownItems: [
			{ id: 1, href: "/services", labelKey: "service1" },
			{ id: 2, href: "/services", labelKey: "service2" },
			{ id: 3, href: "/services", labelKey: "service3" },
		],
	},
	{ href: "/about", labelKey: "about" },
	{ href: "/", labelKey: "home", active: true },
];

interface NavigationProps {
	locale: Locale;
}

export default function Navigation({ locale }: NavigationProps) {
	const t = useTranslations("Navigation");

	return (
		<nav
			className="absolute -top-8 hidden w-full rounded-md bg-custom-primary-accent text-white lg:block"
			dir={locale === "ar" ? "ltr" : "rtl"}
		>
			<div className="container mx-auto flex items-center justify-between px-4 py-3">
				<Link
					href="/login"
					className="flex items-center gap-2 hover:text-custom-tertiary"
				>
					<User className="size-5" />
					{t("loginRegister")}
				</Link>

				<ul className={cn("flex items-center gap-8")}>
					{navItems?.map((item) => (
						<li key={item.href} className="relative">
							{item.hasDropdown ? (
								<DropdownMenu>
									<DropdownMenuTrigger className="flex items-center gap-1 hover:text-custom-tertiary">
										{t(item.labelKey)}
										<ChevronDown className="size-4" />
									</DropdownMenuTrigger>
									<DropdownMenuContent align="end" className="w-48">
										{item.dropdownItems?.map((dropdownItem) => (
											<DropdownMenuItem key={dropdownItem.id}>
												<Link
													href={dropdownItem.href as any}
													className="w-full"
												>
													{t(dropdownItem.labelKey)}
												</Link>
											</DropdownMenuItem>
										))}
									</DropdownMenuContent>
								</DropdownMenu>
							) : (
								<Link
									href={item.href as any}
									className={cn(
										"relative py-2 hover:text-custom-tertiary",
										item.active && "font-bold"
									)}
								>
									{t(item.labelKey)}
									{item.active && (
										<span className="absolute bottom-0 left-1/2 mt-1 size-1.5 -translate-x-1/2 rounded-full bg-background" />
									)}
								</Link>
							)}
						</li>
					))}
				</ul>
			</div>
		</nav>
	);
}
